@@ -201,6 +201,9 @@ __proto__: ModalDialog.ModalDialog.prototype,
     _onKeyPress: function (o, e) {
         let symbol = e.get_key_symbol();
         if (symbol == Clutter.Return || symbol == Clutter.KP_Enter) {
+            if (o.get_text().trim() == "") {
+                return false;
+            }
             this.popModal();
             if (Cinnamon.get_event_state(e) & Clutter.ModifierType.CONTROL_MASK)
                 this._run(o.get_text(), true);
@@ -342,10 +345,11 @@ __proto__: ModalDialog.ModalDialog.prototype,
     },
 
     _run : function(input, inTerminal) {
+        input = input.trim();
         this._history.addItem(input);
         this._commandError = false;
-        if (this._enableInternalCommands && input.trim() in DEVEL_COMMANDS) {
-            DEVEL_COMMANDS[input.trim()]();
+        if (this._enableInternalCommands && input in DEVEL_COMMANDS) {
+            DEVEL_COMMANDS[input]();
             return;
         }
 
@@ -372,7 +376,7 @@ __proto__: ModalDialog.ModalDialog.prototype,
         } catch (e) {
             // Mmmh, that failed - see if @input matches an existing file
             let path = null;
-            input = input.trim();
+
             if (input.charAt(0) == '/') {
                 path = input;
             } else {
@@ -403,7 +407,7 @@ __proto__: ModalDialog.ModalDialog.prototype,
     _showError : function(message) {
         this._commandError = true;
 
-        this._errorMessage.set_text(message);
+        this._errorMessage.set_text(message.trim());
 
         if (!this._errorBox.visible) {
             let [errorBoxMinHeight, errorBoxNaturalHeight] = this._errorBox.get_preferred_height(-1);
